#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasktags
version:              0.73.0
visibility:           public
id:                   hasktags-0.73.0-9IDUS580WL5IctEgrzFreN
key:                  hasktags-0.73.0-9IDUS580WL5IctEgrzFreN
license:              BSD-3-Clause
copyright:            The University Court of the University of Glasgow
maintainer:
    Jack Henahan <jhenahan@me.com>,
    Marc Weber <marco-oweber@gmx.de>,
    Marco Túlio Pimenta Gontijo <marcotmarcot@gmail.com>

author:               The GHC Team
homepage:             http://github.com/MarcWeber/hasktags
synopsis:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs

description:
    Produces ctags "tags" and etags "TAGS" files for Haskell programs.

category:             Development
abi:                  92e93a26cbcb9cd110818c4038f81a80
exposed:              True
exposed-modules:      Hasktags
hidden-modules:       Tags DebugShow
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasktags-0.73.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasktags-0.73.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasktags-0.73.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hasktags
hs-libraries:         HShasktags-0.73.0-9IDUS580WL5IctEgrzFreN
depends:
    base-4.18.2.1 bytestring-0.11.5.3 directory-1.3.8.5
    filepath-1.4.300.1 json-0.10-1QJiKosvYy8EUt14ONR1FW
    microlens-platform-0.4.4.1-9XKDWB6g09KIkDZHeTGCny
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1

haddock-interfaces:   /usr/share/doc/hasktags/html/hasktags.haddock
haddock-html:         /usr/share/doc/hasktags/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

